==> typo3_src-10.3.0.tar.gz: typo3_src-10.3.0/typo3/sysext/scheduler/Classes/Example/SleepTask.php <==
<?php
namespace TYPO3\CMS\Scheduler\Example;

/*
 * This file is part of the TYPO3 CMS project.
 *
 * It is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, either version 2
 * of the License, or any later version.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * The TYPO3 project - inspiring people to share!
 */

/**
 * Provides a task that sleeps for some time
 * This is useful for testing parallel executions
 * @internal This class is an example is not considered part of the Public TYPO3 API.
 */
class SleepTask extends \TYPO3\CMS\Scheduler\Task\AbstractTask
{
    /**
     * Number of seconds the task should be sleeping for
     *
     * @var int
     */
    public $sleepTime = 10;

    /**
     * Function executed from the Scheduler.
     * Goes to sleep ;-)
     *
     * @return bool
     */
    public function execute()
    {
        $time = 10;
        if (!empty($this->sleepTime)) {
            $time = $this->sleepTime;
        }
        sleep($time);
        return true;
    }

    /**
     * This method returns the sleep duration as additional information
     *
     * @return string Information to display
     */
    public function getAdditionalInformation()
    {
        return $this->getLanguageService()->sL('LLL:EXT:scheduler/Resources/Private/Language/locallang.xlf:label.sleepTime') . ': ' . $this->sleepTime;
    }
}

==> typo3_src-10.4.20.tar.gz: typo3_src-10.4.20/typo3/sysext/scheduler/Classes/Example/SleepTask.php <==
<?php

/*
 * This file is part of the TYPO3 CMS project.
 *
 * It is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, either version 2
 * of the License, or any later version.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * The TYPO3 project - inspiring people to share!
 */

namespace TYPO3\CMS\Scheduler\Example;

use TYPO3\CMS\Scheduler\Task\AbstractTask;

/**
 * Provides a task that sleeps for some time
 * This is useful for testing parallel executions
 * @internal This class is an example is not considered part of the Public TYPO3 API.
 */
class SleepTask extends AbstractTask
{
    /**
     * Number of seconds the task should be sleeping for
     *
     * @var int
     */
    public $sleepTime = 10;

    /**
     * Function executed from the Scheduler.
     * Goes to sleep ;-)
     *
     * @return bool
     */
    public function execute()
    {
        $time = 10;
        if (!empty($this->sleepTime)) {
            $time = $this->sleepTime;
        }
        sleep($time);
        return true;
    }

    /**
     * This method returns the sleep duration as additional information
     *
     * @return string Information to display
     */
    public function getAdditionalInformation()
    {
        return $this->getLanguageService()->sL('LLL:EXT:scheduler/Resources/Private/Language/locallang.xlf:label.sleepTime') . ': ' . $this->sleepTime;
    }
}
